@@ -8,7 +8,7 @@ use Carp;
 use File::Spec;
 use File::BaseDir 0.03 qw/data_files data_home/;
 
-our $VERSION = 0.08;
+our $VERSION = 0.09;
 our $VERBOSE = 0;
 
 if ($^O eq 'MSWin32') {
@@ -465,7 +465,7 @@ sub get {
 	return undef unless defined $i;
 	my $lang = join('|', map quotemeta($_), @lang) || 'C';
 	my %matches = ( $$self{groups}[$i] =~
-		/^(\Q$key\E\[(?:$lang)\]|\Q$key\E)\s*=\s*(.*?)\s*$/gm );
+		/^(\Q$key\E\[(?:$lang)\]|\Q$key\E)[^\S\n]*=[^\S\n]*(.*?)\s*$/gm );
 	return undef unless keys %matches;
 
 	# Find preferred value
